EditTicketData

Struct EditTicketData 

pub struct EditTicketData {
    pub subject: String,
    pub status: Status,
    pub description: Option<String>,
    pub requester: Option<UserInfo>,
    pub priority: Option<Priority>,
    pub udf_fields: Option<Value>,
}
Data structure for editing a ticket. Contains fields that WILL be updated on the associated ticket. For some reason SDP does not provide simple API to patch a single attribute of a ticket, instead it requires sending a PUT that will replace all of the fields even None ones, which will be treated as empty values and overwrite existing data.

To conveniently use this API I’d recommend to use From<DetailedTicket> implementation for this struct.

Fields

subject: Stringstatus: Statusdescription: Option<String>requester: Option<UserInfo>priority: Option<Priority>udf_fields: Option<Value>

Dynamically defined template fields