pub struct TicketClient<'a> { /* private fields */ }Expand description
Client for single ticket operations (get, close, assign, notes, merge).
Implementations
Sourceimpl<'a> TicketClient<'a>
impl<'a> TicketClient<'a>
Sourcepub async fn get(&self) -> Result<DetailedTicket, Error>
pub async fn get(&self) -> Result<DetailedTicket, Error>
Get full ticket details.
Sourcepub async fn assign(&self, technician: &str) -> Result<(), Error>
pub async fn assign(&self, technician: &str) -> Result<(), Error>
Assign the ticket to a technician.
pub async fn conversations(&self) -> Result<Value, Error>
pub async fn conversation_content( &self, content_url: &str, ) -> Result<Value, Error>
Sourcepub async fn all_attachment_links(&self) -> Result<Vec<String>, Error>
pub async fn all_attachment_links(&self) -> Result<Vec<String>, Error>
Get all attachment links for the ticket, including conversation attachments including attachments from merged tickets.
Sourcepub async fn add_note(&self, description: &str) -> Result<Note, Error>
pub async fn add_note(&self, description: &str) -> Result<Note, Error>
Add a note to the ticket with default settings.
Sourcepub fn note(&self) -> NoteBuilder<'a>
pub fn note(&self) -> NoteBuilder<'a>
Start building a note with custom settings.